unit Convertor;

interface

type
  TNumericConvertor = class
  private
    FBase: Integer;
  public
    constructor Create (const ABase: Integer);
    property Base: Integer read FBase;
    function ToString (const Value: Integer): string;
    function ToNumber (const Value: string): Integer;
  end;

implementation

{ TNumericConvertor }

constructor TNumericConvertor.Create(const ABase: Integer);
begin
  Assert ((ABase > 1) and (ABase <= 36), 'Illegal Base specfied');
  FBase := ABase;
end;

function TNumericConvertor.ToNumber(const Value: string): Integer;
var
  I, Digit: Integer;
begin
  Result := 0;
  for I:=1 to Length(Value) do begin
    if Value[I] > '9' then
      Digit := Ord(Value[I]) - Ord('A') + 10
    else
      Digit := Ord(Value[I]) - Ord('0');
    Assert ((Digit >= 0) and (Digit < Fbase), 'Illegal character');
    Result := Result * FBase + Digit;
  end;
end;

function TNumericConvertor.ToString(const Value: Integer): string;
var
  Rem, Quot: Integer;
begin
  Assert (Value >= 0, 'Only positive numbers can be converted');
  Result := '';
  Quot := Value;
  while Quot <> 0 do begin
    Rem := Quot mod FBase;
    if Rem >= 10 then
      Result := Char(Rem + Ord('A') - 10) + Result
    else
      Result := Char(Rem + Ord('0')) + Result;
    Quot := Quot div Fbase;
  end;
  if Result = '' then
    Result := '0';
end;

end.
